/*
 * Copyright 2004-2010 the Seasar Foundation and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.seasar.framework.util;

import java.io.Externalizable;
import java.util.Arrays;
import java.util.Map;

/**
 * 配列の性質を併せ持つ {@link Map}です。
 * 
 * @author higa
 * @param <K>
 *            キーの型
 * @param <V>
 *            値の型
 * 
 */
public class ArrayMap<K, V> extends org.seasar.util.collection.ArrayMap<K, V>
        implements Map<K, V>, Cloneable, Externalizable {

    static final long serialVersionUID = 1L;

    /**
     * {@link ArrayMap}を作成します。
     */
    public ArrayMap() {
        this(INITIAL_CAPACITY);
    }

    /**
     * {@link ArrayMap}を作成します。
     * 
     * @param initialCapacity
     */
    public ArrayMap(int initialCapacity) {
        super(initialCapacity);
    }

    /**
     * {@link ArrayMap}を作成します。
     * 
     * @param map
     */
    public ArrayMap(Map<? extends K, ? extends V> map) {
        super(map);
    }

    /**
     * indexに対応する値を返します。
     * 
     * @param index
     * @return indexに対応する値
     */
    public final V get(final int index) {
        return getAt(index);
    }

    /**
     * indexに対応するキーを返します。
     * 
     * @param index
     * @return indexに対応するキー
     */
    public final K getKey(final int index) {
        return getKeyAt(index);
    }

    /**
     * indexに対応する {@link java.util.Map.Entry}を返します。
     * 
     * @param index
     * @return indexに対応する {@link java.util.Map.Entry}
     */
    public final Map.Entry<K, V> getEntry(final int index) {
        return getEntryAt(index);
    }

    /**
     * indexに対応する値を設定します。
     * 
     * @param index
     * @param value
     */
    public final void set(final int index, final V value) {
        setAt(index, value);
    }

    @Override
    public Object clone() {
        final ArrayMap<K, V> copy = new ArrayMap<K, V>();
        copy.threshold = threshold;
        copy.mapTable = Arrays.copyOf(mapTable, size);
        copy.listTable = Arrays.copyOf(listTable, size);
        copy.size = size;
        return copy;
    }
}