/*
 * Copyright 2004-2010 the Seasar Foundation and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.seasar.framework.util;

import java.lang.reflect.Array;
import java.util.Arrays;

/**
 * 配列に対するユーティリティクラスです。
 * 
 * @author higa
 * 
 */
public class ArrayUtil extends org.seasar.util.collection.ArrayUtil {

    /**
     * インスタンスを構築します。
     */
    protected ArrayUtil() {
    }

    /**
     * 配列を文字列に変換します。
     * 
     * @param array
     * @return 配列の文字列表現
     */
    public static String toString(Object[] array) {
        return Arrays.toString(array);
    }

    /**
     * <code>primitive</code>型を考慮して配列に値を設定します。
     * 
     * @param array
     * @param valueType
     * @param value
     * @param index
     */
    public static void setArrayValue(Object array, Class<?> valueType,
            Object value, int index) {
        // TODO 互換性のために残す
        if (value == null) {
            return;
        }
        if (valueType == int.class) {
            Array.setInt(array, index,
                    IntegerConversionUtil.toPrimitiveInt(value));
        } else if (valueType == double.class) {
            Array.setDouble(array, index,
                    DoubleConversionUtil.toPrimitiveDouble(value));
        } else if (valueType == long.class) {
            Array.setLong(array, index,
                    LongConversionUtil.toPrimitiveLong(value));
        } else if (valueType == float.class) {
            Array.setFloat(array, index,
                    FloatConversionUtil.toPrimitiveFloat(value));
        } else if (valueType == short.class) {
            Array.setShort(array, index,
                    ShortConversionUtil.toPrimitiveShort(value));
        } else if (valueType == boolean.class) {
            Array.setBoolean(array, index,
                    BooleanConversionUtil.toPrimitiveBoolean(value));
        } else if (valueType == char.class) {
            Array.setChar(array, index, ((Character) value).charValue());
        }
        Array.set(array, index, value);
    }

}
